Learn R Programming

EQUIVNONINF (version 1.0.2)

bi1st: Critical constants and power of the UMP test for equivalence of a single binomial proportion to some given reference value

Description

The function computes the critical constants defining the uniformly most powerful (randomized) test for the problem \(p \le p_1\) or \(p \ge p_2\) versus \(p_1 < p < p_2\), with \(p\) denoting the parameter of a binomial distribution from which a single sample of size \(n\) is available. In the output, one also finds the power against the alternative that the true value of \(p\) falls on the midpoint of the hypothetical equivalence interval \((p_1 , p_2).\)

Usage

bi1st(alpha,n,P1,P2)

Arguments

alpha

significance level

n

sample size

P1

lower limit of the hypothetical equivalence range for the binomial parameter \(p\)

P2

upper limit of the hypothetical equivalence range for \(p\)

Value

alpha

significance level

n

sample size

P1

lower limit of the hypothetical equivalence range for the binomial parameter \(p\)

P2

upper limit of the hypothetical equivalence range for \(p\)

C1

left-hand limit of the critical interval for the observed number \(X\) of successes

C2

right-hand limit of the critical interval for \(X\)

GAM1

probability of rejecting the null hypothesis when it turns out that \(X=C_1\)

GAM2

probability of rejecting the null hypothesis for \(X=C_2\)

POWNONRD

Power of the nonrandomized version of the test against the alternative \(p = (p_1+p_2)/2\)

POW

Power of the randomized UMP test against the alternative \(p = (p_1+p_2)/2\)

References

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 4.3.

Examples

Run this code
# NOT RUN {
bi1st(.05,273,.65,.75)
# }

Run the code above in your browser using DataLab