bi2aeq1: Power of the exact Fisher type test for equivalence
Description
The function computes exact values of the power of the randomized UMPU test for
equivalence in the strict (i.e. two-sided) sense of two binomial distributions and the
conservative nonrandomized version of that test. It is assumed that the samples
being available from both distributions are independent.
Usage
bi2aeq1(m,n,rho1,rho2,alpha,p1,p2)
Arguments
m
size of Sample 1
n
size of Sample 2
rho1
lower limit of the hypothetical equivalence range for the odds ratio
rho2
upper limit of the hypothetical equivalence range for the odds ratio
alpha
significance level
p1
true success rate in Population 1
p2
true success rate in Population 2
Value
m
size of Sample 1
n
size of Sample 2
rho1
lower limit of the hypothetical equivalence range for the odds ratio
rho2
upper limit of the hypothetical equivalence range for the odds ratio
alpha
significance level
p1
true success rate in Population 1
p2
true success rate in Population 2
POWNR
Power of the nonrandomized version of the test
POW
Power of the randomized UMPU test
References
Wellek S: Testing statistical hypotheses of equivalence and noninferiority.
Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 6.6.4.