The function computes minimum sample sizes required in the randomized UMPU test for equivalence of two binomial distributions with respect to the odds ratio. Computation is done under the side condition that the ratio \(m/n\) has some predefined value \(\lambda\).
bi2aeq2(rho1,rho2,alpha,p1,p2,beta,qlambd)lower limit of the hypothetical equivalence range for the odds ratio
upper limit of the hypothetical equivalence range for the odds ratio
significance level
true success rate in Population 1
true success rate in Population 2
target value of power
sample size ratio \(m/n\)
lower limit of the hypothetical equivalence range for the odds ratio
upper limit of the hypothetical equivalence range for the odds ratio
significance level
true success rate in Population 1
true success rate in Population 2
target value of power
sample size ratio \(m/n\)
minimum size of Sample 1
minimum size of Sample 2
Power of the randomized UMPU test attained with the computed values of m,n
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 6.6.4.
# NOT RUN {
bi2aeq2(0.5,2.0,0.05,0.5,0.5,0.60,1.0)
# }
Run the code above in your browser using DataLab