Implementation of the construction described on pp. 179--181 of Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition.
bi2by_ni_OR(N1,N2,EPS,SW,NSUB,ALPHA,MAXH)size of sample 1
size of sample 2
noninferiority margin to the deviation of the odds ratio from unity
width of the search grid for determining the maximum of the rejection probability on the common boundary of the hypotheses
number of subintervals for partitioning the range of integration
target significance level
maximum number of interval halving steps to be carried out in finding the maximally admissible nominal level
size of sample 1
size of sample 2
noninferiority margin to the deviation of the odds ratio from unity
number of subintervals for partitioning the range of integration
width of the search grid for determining the maximum of the rejection probability on the common boundary of the hypotheses
result of the search for the largest admissible nominal level
size of the critical region corresponding to \(\alpha_0\)
size of the critical region of the test at uncorrected nominal level
The program uses 96-point Gauss-Legendre quadrature on each of the NSUB intervals into which the range of integration is partitioned.
Wellek S: Statistical methods for the analysis of two-arm non-inferiority trials with binary outcomes. Biometrical Journal 47 (2005), 48--61.
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 6.6.2.
# NOT RUN {
bi2by_ni_OR(10,10,1/3,.0005,10,.05,12)
# }
Run the code above in your browser using DataLab