The program computes exact values of the rejection probability of the asymptotic test for equivalence in the sense of \(-\delta_1 < p_1-p_2 < \delta_2\), at any nominal level \(\alpha_0\). [The largest \(\alpha_0\) for which the test is valid in terms of the significance level, can be computed by means of the program bi2diffac.]
bi2dipow(alpha0,m,n,del1,del2,p1,p2)nominal significance level
size of Sample 1
size of Sample 2
absolute value of the lower limit of the hypothetical equivalence range for \(p_1-p_2\)
upper limit of the hypothetical equivalence range for \(p_1-p_2\)
true value of the success probability in Population 1
true value of the success probability in Population 2
nominal significance level
size of Sample 1
size of Sample 2
absolute value of the lower limit of the hypothetical equivalence range for \(p_1-p_2\)
upper limit of the hypothetical equivalence range for \(p_1-p_2\)
true value of the success probability in Population 1
true value of the success probability in Population 2
exact rejection probability under \((p_1,p_2)\) of the test at nominal level \(\alpha_0\) for equivalence of two binomial distributions with respect to the difference of the success probabilities
error indicator answering the question of whether or not the sufficient condition for the correctness of the result output by the program, was satisfied
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 6.6.6.
# NOT RUN {
bi2dipow(0.0228,50,50,0.20,0.20,0.50,0.50)
# }
Run the code above in your browser using DataLab