bi2rlv1: Power of the exact Fisher type test for relevant differences
Description
The function computes exact values of the power of the randomized UMPU test for relevant
differences between two binomial distributions and the conservative nonrandomized version of that test.
It is assumed that the samples being available from both distributions are independent.
Usage
bi2rlv1(m,n,rho1,rho2,alpha,p1,p2)
Arguments
m
size of Sample 1
n
size of Sample 2
rho1
lower limit of the hypothetical equivalence range for the odds ratio
rho2
upper limit of the hypothetical equivalence range for the odds ratio
alpha
significance level
p1
true success rate in Population 1
p2
true success rate in Population 2
Value
m
size of Sample 1
n
size of Sample 2
rho1
lower limit of the hypothetical equivalence range for the odds ratio
rho2
upper limit of the hypothetical equivalence range for the odds ratio
alpha
significance level
p1
true success rate in Population 1
p2
true success rate in Population 2
POWNR
power of the nonrandomized version of the test
POW
power of the randomized UMPU test
References
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition.
Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 11.3.3.