Learn R Programming

EQUIVNONINF (version 1.0.2)

bi2ste1: Power of the exact Fisher type test for noninferiority

Description

The function computes exact values of the power of the randomized UMPU test for one-sided equivalence of two binomial distributions and its conservative nonrandomized version. It is assumed that the samples being available from both distributions are independent.

Usage

bi2ste1(m, n, eps, alpha, p1, p2)

Arguments

m

size of Sample 1

n

size of Sample 2

eps

noninferiority margin to the odds ratio \(\varrho\), defined to be the maximum acceptable deviation of the true value of \(\varrho\) from unity

alpha

significance level

p1

success rate in Population 1

p2

success rate in Population 2

Value

m

size of Sample 1

n

size of Sample 2

eps

noninferiority margin to the odds ratio \(\varrho\), defined to be the maximum acceptable deviation of the true value of \(\varrho\) from unity

alpha

significance level

p1

success rate in Population 1

p2

success rate in Population 2

POWNR

power of the nonrandomized version of the test

POW

power of the randomized UMPU test

%% ...

References

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, 6.6.1.

Examples

Run this code
# NOT RUN {
bi2ste1(106,107,0.5,0.05,0.9245,0.9065)
# }

Run the code above in your browser using DataLab