The objective is to raise the nominal significance level as far as possible without exceeding the target significance level in the nonrandomized version of the test. The approach goes back to R.D. Boschloo (1970) who used the same technique for reducing the conservatism of the traditional nonrandomized Fisher test for superiority.
bi2ste3(m, n, eps, alpha, sw, tolrd, tol, maxh)size of Sample 1
size of Sample 2
noninferiority margin to the odds ratio \(\varrho\), defined to be the maximum acceptable deviation of the true value of \(\varrho\) from unity
target significance level
width of the search grid for determining the maximum of the rejection probability on the common boundary of the hypotheses
horizontal distance from 0 and 1, respectively, of the left- and right-most boundary point to be included in the search grid
upper bound to the absolute difference between size and target level below which the search for a corrected nominal level terminates
maximum number of interval-halving steps to be carried out in finding the maximally raised nominal level
size of Sample 1
size of Sample 2
noninferiority margin to the odds ratio \(\varrho\), defined to be the maximum acceptable deviation of the true value of \(\varrho\) from unity
target significance level
width of the search grid for determining the maximum of the rejection probability on the common boundary of the hypotheses
horizontal distance from 0 and 1, respectively, of the left- and right-most boundary point to be included in the search grid
upper bound to the absolute difference between size and target level below which the search for a corrected nominal level terminates
maximum number of interval-halving steps to be carried out in finding the maximally raised nominal level
current trial value of the raised nominal level searched for
number of interval-halving steps performed up to now
size of the critical region corresponding to \(\alpha_0\)
It should be noted that, as the function of the nominal level, the size of the nonrandomized test is piecewise constant. Accordingly, there is a nondegenerate interval of "candidate" nominal levels serving the purpose. The limits of such an interval can be read from the output.
Boschloo RD: Raised conditional level of significance for the 2 x 2- table when testing the equality of two probabilities. Statistica Neerlandica 24 (1970), 1-35.
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\)6.6.2.
# NOT RUN {
bi2ste3(50, 50, 1/3, 0.05, 0.05, 1e-10, 1e-8, 10)
# }
Run the code above in your browser using DataLab