Implementation of the construction described on pp. 183-5 of Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition.
bi2wld_ni_del(N1,N2,EPS,SW,ALPHA,MAXH)size of Sample 1
size of Sample 2
noninferiority margin to the difference of success probabilities
width of the search grid for determining the maximum of the rejection probability on the common boundary of the hypotheses
target significance level
maximum number of interval-halving steps
size of Sample 1
size of Sample 2
noninferiority margin to the difference of success probabilities
width of the search grid for determining the maximum of the rejection probability on the common boundary of the hypotheses
target significance level
maximum number of interval-halving steps
corrected nominal level
size of the critical region of the test at nominal level ALPHA0
size of the test at uncorrected nominal level ALPHA
indicator taking value 1 when it occurs that the sufficient condition allowing one to restrict the search for the maximum of the rejection probability under the null hypothesis to its boundary, fails to be satisfied; otherwise the indicator retains its default value 0.
The program computes the largest nominal significance level to be used for determining the critical lower bound to the Wald-type statistic for the problem of testing \(H:p_1 \le p_2 - \varepsilon\) versus \(K: p_1 < p_2 - \varepsilon\).
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 6.6.3.
# NOT RUN {
bi2wld_ni_del(25,25,.10,.01,.05,10)
# }
Run the code above in your browser using DataLab