Learn R Programming

EQUIVNONINF (version 1.0.2)

cf_reh_exact: Exact confidence bounds to the relative excess heterozygosity (REH) exhibited by a SNP genotype distribution

Description

Implementation of the interval estimation procedure described on pp. 305-6 of Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition.

Usage

cf_reh_exact(X1,X2,X3,alpha,SW,TOL,ITMAX)

Arguments

X1

count of homozygotes of the first kind [\(\leftrightarrow\) genotype AA]

X2

count of heterozygotes [\(\leftrightarrow\) genotype AB]

X3

count of homozygotes of the second kind [\(\leftrightarrow\) genotype BB]

alpha

1 - confidence level

SW

width of the search grid for determining an interval covering the parameter point at which the conditional distribution function takes value \(\alpha\) and \(1-\alpha\), respectively

TOL

numerical tolerance to the deviation between the computed confidence limits and their exact values

ITMAX

maximum number of interval-halving steps

Value

X1

count of homozygotes of the first kind [\(\leftrightarrow\) genotype AA]

X2

count of heterozygotes [\(\leftrightarrow\) genotype AB]

X3

count of homozygotes of the second kind [\(\leftrightarrow\) genotype BB]

alpha

1 - confidence level

SW

width of the search grid for determining an interval covering the parameter point at which the conditional distribution function takes value \(\alpha\) and \(1-\alpha\), respectively

TOL

numerical tolerance to the deviation between the computed confidence limits and their exact values

ITMAX

maximum number of interval-halving steps

C_l_exact

exact conditional lower \((1-\alpha)\)-confidence bound to REH

C_r_exact

exact conditional upper \((1-\alpha)\)-confidence bound to REH

Details

The program exploits the structure of the family of all genotype distributions, which is 2-parameter exponential with \(\log(REH)\) as one of these parameters.

References

Wellek S, Goddard KAB, Ziegler A: A confidence-limit-based approach to the assessment of Hardy-Weinberg equilibrium. Biometrical Journal 52 (2010), 253-270.

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 9.4.3.

Examples

Run this code
# NOT RUN {
cf_reh_exact(34,118,96,.05,.1,1E-4,25)
# }

Run the code above in your browser using DataLab