Learn R Programming

EQUIVNONINF (version 1.0.2)

cf_reh_midp: Mid-p-value - based confidence bounds to the relative excess heterozygosity (REH) exhibited by a SNP genotype distribution

Description

Implementation of the interval estimation procedure described on pp. 306-7 of Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition.

Usage

cf_reh_midp(X1,X2,X3,alpha,SW,TOL,ITMAX)

Arguments

X1

count of homozygotes of the first kind [\(\leftrightarrow\) genotype AA]

X2

count of heterozygotes [\(\leftrightarrow\) genotype AB]

X3

count of homozygotes of the second kind [\(\leftrightarrow\) genotype BB]

alpha

1 - confidence level

SW

width of the search grid for determining an interval covering the parameter point at which the conditional distribution function takes value \(\alpha\) and \(1-\alpha\), respectively

TOL

numerical tolerance to the deviation between the computed confidence limits and their exact values

ITMAX

maximum number of interval-halving steps

Value

X1

count of homozygotes of the first kind [\(\leftrightarrow\) genotype AA]

X2

count of heterozygotes [\(\leftrightarrow\) genotype AB]

X3

count of homozygotes of the second kind [\(\leftrightarrow\) genotype BB]

alpha

1 - confidence level

SW

width of the search grid for determining an interval covering the parameter point at which the conditional distribution function takes value \(\alpha\) and \(1-\alpha\), respectively

TOL

numerical tolerance to the deviation between the computed confidence limits and their exact values

ITMAX

maximum number of interval-halving steps

C_l_midp

lower \((1-\alpha)\)-confidence bound to REH based on conditional mid-p-values

C_r_midp

upper \((1-\alpha)\)-confidence bound to REH based on conditional mid-p-values

Details

The mid-p algorithm serves as a device for reducing the conservatism inherent in exact confidence estimation procedures for parameters of discrete distributions.

References

Agresti A: Categorical data Analysis (2nd edn). Hoboken, NJ: Wiley, Inc., 2002, Section 1.4.5.

Wellek S, Goddard KAB, Ziegler A: A confidence-limit-based approach to the assessment of Hardy-Weinberg equilibrium. Biometrical Journal 52 (2010), 253-270.

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 9.4.3.

Examples

Run this code
# NOT RUN {
cf_reh_midp(137,34,8,.05,.1,1E-4,25)
# }

Run the code above in your browser using DataLab