Learn R Programming

EQUIVNONINF (version 1.0.2)

exp1st: Critical constants and power against the null alternative of the UMP test for equivalence of the hazard rate of a single exponential distribution to some given reference value

Description

The function computes the critical constants defining the uniformly most powerful test for the problem \(\sigma \le 1/(1 + \varepsilon)\) or \(\sigma\ge (1 + \varepsilon)\) versus \(1/(1 + \varepsilon) < \sigma < (1 + \varepsilon)\), with \(\sigma\) denoting the scale parameter [\(\equiv\) reciprocal hazard rate] of an exponential distribution.

Usage

exp1st(alpha,tol,itmax,n,eps)

Arguments

alpha

significance level

tol

tolerable deviation from \(\alpha\) of the rejection probability at either boundary of the hypothetical equivalence interval

itmax

maximum number of iteration steps

n

sample size

eps

margin determining the hypothetical equivalence range symmetrically on the log-scale

Value

alpha

significance level

tol

tolerable deviation from \(\alpha\) of the rejection probability at either boundary of the hypothetical equivalence interval

itmax

maximum number of iteration steps

n

sample size

eps

margin determining the hypothetical equivalence range symmetrically on the log-scale

IT

number of iteration steps performed until reaching the stopping criterion corresponding to TOL

C1

left-hand limit of the critical interval for \(T =\sum_{i=1}^n X_i\)

C2

right-hand limit of the critical interval for \(T =\sum_{i=1}^n X_i\)

ERR1

deviation of the rejection probability from \(\alpha\) under \(\sigma = 1/(1 + \varepsilon)\)

POW0

power of the randomized UMP test against the alternative \(\sigma = 1\)

References

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 4.2.

Examples

Run this code
# NOT RUN {
exp1st(0.05,1.0e-10,100,80,0.3)
# }

Run the code above in your browser using DataLab