Learn R Programming

EQUIVNONINF (version 1.0.2)

fstretch: Critical constants and power of the UMPI (uniformly most powerful invariant) test for dispersion equivalence of two Gaussian distributions

Description

The function computes the critical constants defining the optimal test for the problem \(\sigma^2/\tau^2 \le \varrho_1\) or \(\sigma^2/\tau^2 \ge \varrho_2\) versus \(\varrho_1 < \sigma^2/\tau^2 < \varrho_2\), with \((\varrho_1,\varrho_2)\) as a fixed nonempty interval around unity.

Usage

fstretch(alpha,tol,itmax,ny1,ny2,rho1,rho2)

Arguments

alpha

significance level

tol

tolerable deviation from \(\alpha\) of the rejection probability at either boundary of the hypothetical equivalence interval

itmax

maximum number of iteration steps

ny1

number of degrees of freedom of the estimator of \(\sigma^2\)

ny2

number of degrees of freedom of the estimator of \(\tau^2\)

rho1

lower equivalence limit to \(\sigma^2/\tau^2\)

rho2

upper equivalence limit to \(\sigma^2/\tau^2\)

Value

alpha

significance level

tol

tolerable deviation from \(\alpha\) of the rejection probability at either boundary of the hypothetical equivalence interval

itmax

maximum number of iteration steps

ny1

number of degrees of freedom of the estimator of \(\sigma^2\)

ny2

number of degrees of freedom of the estimator of \(\tau^2\)

rho1

lower equivalence limit to \(\sigma^2/\tau^2\)

rho2

upper equivalence limit to \(\sigma^2/\tau^2\)

IT

number of iteration steps performed until reaching the stopping criterion corresponding to TOL

C1

left-hand limit of the critical interval for $$T = \frac{n-1}{m-1} \sum_{i=1}^m (X_i-\overline{X})^2 / \sum_{j=1}^{n-1} (Y_j-\overline{Y})^2$$

C2

right-hand limit of the critical interval for $$T = \frac{n-1}{m-1} \sum_{i=1}^m (X_i-\overline{X})^2 / \sum_{j=1}^{n-1} (Y_j-\overline{Y})^2$$

ERR

deviation of the rejection probability from \(\alpha\) under \(\sigma^2/\tau^2 = \varrho_1\)

POW0

power of the UMPI test against the alternative \(\sigma^2/\tau^2 = 1\)

References

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 6.5.

Examples

Run this code
# NOT RUN {
fstretch(0.05, 1.0e-10, 50,40,45,0.5625,1.7689)
# }

Run the code above in your browser using DataLab