Learn R Programming

EQUIVNONINF (version 1.0.2)

gofhwex: Critical constants of the exact UMPU test for approximate compatibility of a SNP genotype distribution with the Hardy-Weinberg model

Description

The function computes the critical constants defining the uniformly most powerful unbiased test for equivalence of the population distribution of the three genotypes distinguishable in terms of a single nucleotide polymorphism (SNP), to a distribution being in Hardy-Weinberg equilibrium (HWE). The test is conditional on the total count \(S\) of alleles of the kind of interest, and the parameter \(\theta\), in terms of which equivalence shall be established, is defined by \(\theta = \frac{\pi_2^2}{\pi_1(1-\pi_1-\pi_2)}\), with \(\pi_1\) and \(\pi_2\) denoting the population frequence of homozygotes of the 1st kind and heterozygotes, respectively.

Usage

gofhwex(alpha,n,s,del1,del2)

Arguments

alpha

significance level

n

number of genotyped individuals

s

observed count of alleles of the kind of interest

del1

absolute value of the lower equivalence limit to \(\theta/4 - 1\)

del2

upper equivalence limit to \(\theta/4 - 1\)

Value

alpha

significance level

n

number of genotyped individuals

s

observed count of alleles of the kind of interest

del1

absolute value of the lower equivalence limit to \(\theta/4 - 1\)

del2

upper equivalence limit to \(\theta/4 - 1\)

C1

left-hand limit of the critical interval for the observed number \(X_2\) of heterozygotes

C2

right-hand limit of the critical interval for the observed number \(X_2\)

GAM1

probability of rejecting the null hypothesis when it turns out that \(X_2=C_1\)

GAM2

probability of rejecting the null hypothesis for \(X_2=C_2\)

References

Wellek S: Tests for establishing compatibility of an observed genotype distribution with Hardy-Weinberg equilibrium in the case of a biallelic locus. Biometrics 60 (2004), 694-703.

Goddard KAB, Ziegler A, Wellek S: Adapting the logical basis of tests for Hardy-Weinberg equilibrium to the real needs of association studies in human and medical genetics. Genetic Epidemiology 33 (2009), 569-580.

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 9.4.2.

Examples

Run this code
# NOT RUN {
gofhwex(0.05,475,429,1-1/1.96,0.96)
# }

Run the code above in your browser using DataLab