Learn R Programming

EQUIVNONINF (version 1.0.2)

gofhwex_1s: Critical constants of the exact UMPU test for absence of a substantial deficit of heterozygotes as compared with a HWE-compliant SNP genotype distribution [noninferiority version of the test implemented by means of gofhwex]

Description

The function computes the critical constants defining the UMPU test for one-sided equivalence of the population distribution of a SNP, to a distribution being in Hardy-Weinberg equilibrium (HWE). A substantial deficit of heterozygotes is defined to occur when the true value of the parametric function \(\omega = \frac{\pi_2/2}{\sqrt{\pi_1\pi_3}}\) [called relative excess heterozygosity (REH)] falls below unity by more than some given margin \(\delta_0\). Like its two-sided counterpart [see the description of the R function gofhwex], the test is conditional on the total count \(S\) of alleles of the kind of interest.

Usage

gofhwex_1s(alpha,n,s,del0)

Arguments

alpha

significance level

n

number of genotyped individuals

s

observed count of alleles of the kind of interest

del0

noninferiority margin for \(\omega\), which has to satisfy \(\omega > 1-\delta_0\) under the alternative hypothesis to be established

Value

alpha

significance level

n

number of genotyped individuals

s

observed count of alleles of the kind of interest

del0

noninferiority margin for \(\omega\), which has to satisfy \(\omega > 1-\delta_0\) under the alternative hypothesis to be established

C

left-hand limit of the critical interval for the observed number \(X_2\) of heterozygotes

GAM

probability of rejecting the null hypothesis when it turns out that \(X_2=C\)

References

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, pp. 300-302.

Examples

Run this code
# NOT RUN {
gofhwex_1s(0.05,133,65,1-1/1.96)
# }

Run the code above in your browser using DataLab