The function computes all quantities required for carrying out the asymptotic test for approximate independence of two categorial variables derived in \(\S\) 9.2 of Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition.
gofind_t(alpha,r,s,eps,xv)significance level
number of rows of the contingency table under analysis
number of columns of the contingency table under analysis
margin to the Euclidean distance between the vector \(\mathbf{\pi}\) of true cell probabilities and the associated vector of products of marginal totals
row vector of length \(r\cdot s\) whose \((i-1)s + j\)-th component is the entry in cell \((i,j)\) of the \(r\times s\) contingency table under analysis \(i=1,\ldots,r\), \(j=1,\ldots,s\).
size of the sample to which the input table relates
significance level
number of rows of the contingency table under analysis
number of columns of the contingency table under analysis
margin to the Euclidean distance between the vector \(\mathbf{\pi}\) of true cell probabilities and the associated vector of products of marginal totals
observed cell counts
observed value of the squared Euclidean distance
square root of the estimated asymtotic variance of \(\sqrt{n}DSQ\_OBS\)
upper critical bound to \(\sqrt{n}DSQ\_OBS\)
indicator of a positive [=1] vs negative [=0] rejection decision to be taken with the data under analysis
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 9.2.
# NOT RUN {
xv <- c(8, 13, 15, 6, 19, 21, 31, 7)
gofind_t(0.05,2,4,0.15,xv)
# }
Run the code above in your browser using DataLab