Learn R Programming

EQUIVNONINF (version 1.0.2)

gofsimpt: Establishing goodness of fit of an observed to a fully specified multinomial distribution: test statistic and critical bound

Description

The function computes all quantities required for carrying out the asymptotic test for goodness rather than lack of fit of an observed to a fully specified multinomial distribution derived in \(\S\) 9.1 of Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition.

Usage

gofsimpt(alpha,n,k,eps,x,pio)

Arguments

alpha

significance level

n

sample size

k

number of categories

eps

margin to the Euclidean distance between the vectors \(\mathbf{\pi}\) and \(\mathbf{\pi}_0\) of true and hypothesized cell probabilities

x

vector of length \(k\) with the observed cell counts as components

pio

prespecified vector of cell probabilities

Value

alpha

significance level

n

sample size

k

number of categories

eps

margin to the Euclidean distance between the vectors \(\mathbf{\pi}\) and \(\mathbf{\pi}_0\) of true and hypothesized cell probabilities

X(1,K)

observed cell counts

PI0(1,K)

hypothecized cell probabilities

DSQPIH_0

observed value of the squared Euclidean distance

VN_N

square root of the estimated asymtotic variance of \(\sqrt{n}DSQPIH\_0\)

CRIT

upper critical bound to \(\sqrt{n}DSQPIH\_0\)

REJ

indicator of a positive [=1] vs negative [=0] rejection decision to be taken with the data under analysis

References

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 9.1.

Examples

Run this code
# NOT RUN {
x<- c(17,16,25,9,16,17)
pio <- rep(1,6)/6
gofsimpt(0.05,100,6,0.15,x,pio)
# }

Run the code above in your browser using DataLab