Learn R Programming

EQUIVNONINF (version 1.0.2)

mawi: Mann-Whitney test for equivalence of two continuous distributions of arbitrary shape: test statistic and critical upper bound

Description

Implementation of the asymptotically distribution-free test for equivalence of two continuous distributions in terms of the Mann-Whitney-Wilcoxon functional. For details see Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition, \(\S\) 6.2.

Usage

mawi(alpha,m,n,eps1_,eps2_,x,y)

Arguments

alpha

significance level

m

size of Sample 1

n

size of Sample 2

eps1_

absolute value of the left-hand limit of the hypothetical equivalence range for \(\pi_+ - 1/2\)

eps2_

right-hand limit of the hypothetical equivalence range for \(\pi_+ - 1/2\)

x

row vector with the \(m\) observations making up Sample1 as components

y

row vector with the \(n\) observations making up Sample2 as components

Value

alpha

significance level

m

size of Sample 1

n

size of Sample 2

eps1_

absolute value of the left-hand limit of the hypothetical equivalence range for \(\pi_+ - 1/2\)

eps2_

right-hand limit of the hypothetical equivalence range for \(\pi_+ - 1/2\)

W+

observed value of the \(U\)-statistics estimator of \(\pi_+\)

SIGMAH

square root of the estimated asymtotic variance of \(W_+\)

CRIT

upper critical bound to \(|W_+ - 1/2 - (\varepsilon^\prime_2-\varepsilon^\prime_1)/2|/\hat{\sigma}\)

REJ

indicator of a positive [=1] vs negative [=0] rejection decision to be taken with the data under analysis

Details

Notation: \(\pi_+\) stands for the Mann-Whitney functional defined by \(\pi_+ = P[X>Y]\), with \(X\sim F \equiv\) cdf of Population 1 being independent of \(Y\sim G \equiv\) cdf of Population 2.

References

Wellek S: A new approach to equivalence assessment in standard comparative bioavailability trials by means of the Mann-Whitney statistic. Biometrical Journal 38 (1996), 695-710.

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 6.2.

Examples

Run this code
# NOT RUN {
x <- c(10.3,11.3,2.0,-6.1,6.2,6.8,3.7,-3.3,-3.6,-3.5,13.7,12.6)
y <- c(3.3,17.7,6.7,11.1,-5.8,6.9,5.8,3.0,6.0,3.5,18.7,9.6)
mawi(0.05,12,12,0.1382,0.2602,x,y)
# }

Run the code above in your browser using DataLab