Learn R Programming

EQUIVNONINF (version 1.0.2)

mcnby_ni_pp: Computation of the posterior probability of the alternative hypothesis of noninferiority in the McNemar setting, given a specific point in the sample space

Description

Evaluation of the integral on the right-hand side of Equation (5.24) on p. 88 of Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition.

Usage

mcnby_ni_pp(N,DEL0,N10,N01)

Arguments

N

sample size

DEL0

noninferiority margin to the difference of the parameters of the marginal binomial distributions under comparison

N10

count of pairs with \((X,Y) = (1,0)\)

N01

count of pairs with \((X,Y) = (0,1)\)

Value

N

sample size

DEL0

noninferiority margin to the difference of the parameters of the marginal binomial distributions under comparison

N10

count of pairs with \((X,Y) = (1,0)\)

N01

count of pairs with \((X,Y) = (0,1)\)

PPOST

posterior probability of the alternative hypothesis \(K_1: \delta > -\delta_0\) with respect to the noninformative prior determined according to Jeffrey's rule

Details

The program uses 96-point Gauss-Legendre quadrature on each of 10 subintervals into which the range of integration is partitioned.

References

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 5.2.3.

Examples

Run this code
# NOT RUN {
mcnby_ni_pp(72,0.05,4,5)
# }

Run the code above in your browser using DataLab