The program computes the largest nominal significance level which can be substituted for the target level \(\alpha\) without making the exact size of the asymptotic testing procedure larger than \(\alpha\).
mcnemasc(alpha,n,del0,sw,tol,maxh)significance level
sample size
upper limit set to \(|p_{10}-p_{01}|\) under the alternative hypothesis of equivalence, with \(p_{10}\) and \(p_{01}\) denoting the probabilities of discordant pairs of both kinds
width of the search grid for determining the maximum of the rejection probability on the common boundary of the hypotheses
upper bound to the absolute difference between size and target level below which the search for a corrected nominal level terminates
maximum number of interval halving steps to be carried out in finding the maximally raised nominal level
significance level
sample size
upper limit set to \(|p_{10}-p_{01}|\) under the alternative hypothesis of equivalence, with \(p_{10}\) and \(p_{01}\) denoting the probabilities of discordant pairs of both kinds
width of the search grid for determining the maximum of the rejection probability on the common boundary of the hypotheses
value of the corrected nominal level obtained after nh steps
number of interval-halving steps actually performed
error indicator messaging "!!!!!" if the sufficient condition for the correctness of the result output by the program was found violated
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 5.2.2.
# NOT RUN {
mcnemasc(0.05,50,0.20,0.05,0.0005,5)
# }
Run the code above in your browser using DataLab