The program computes exact values of the rejection probability of the asymptotic test for equivalence in the sense of \(-\delta_0 < p_{10}-p_{01} < \delta_0\), at any nominal level \(\alpha\). [The largest \(\alpha\) for which the test is valid in terms of the significance level, can be computed by means of the program mcnemasc.]
mcnempow(alpha,n,del0,p10,p01)nominal significance level
sample size
upper limit set to \(|\delta|\) under the alternative hypothesis of equivalence
true value of \(P[X=1,Y=0]\)
true value of \(P[X=0,Y=1]\)
nominal significance level
sample size
upper limit set to \(|\delta|\) under the alternative hypothesis of equivalence
true value of \(P[X=1,Y=0]\)
true value of \(P[X=0,Y=1]\)
exact rejection probability of the asymptotic McNemar test for equivalence at nominal level \(\alpha\)
error indicator messaging "!!!!!" if the sufficient condition for the correctness of the result output by the program was found violated
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, p.84.
# NOT RUN {
mcnempow(0.024902,50,0.20,0.30,0.30)
# }
Run the code above in your browser using DataLab