Learn R Programming

EQUIVNONINF (version 1.0.2)

mwtie_fr: Analogue of mwtie_xy for settings with grouped data

Description

Implementation of the asymptotically distribution-free test for equivalence of discrete distributions from which grouped data are obtained. Hypothesis formulation is in terms of the Mann-Whitney-Wilcoxon functional generalized to the case that ties between observations from different distributions may occur with positive probability. For details see Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition, p.155.

Usage

mwtie_fr(k,alpha,m,n,eps1_,eps2_,x,y)

Arguments

k

total number of grouped values which can be distinguished in the pooled sample

alpha

significance level

m

size of Sample 1

n

size of Sample 2

eps1_

absolute value of the left-hand limit of the hypothetical equivalence range for \(\pi_+/(1-\pi_0) - 1/2\)

eps2_

right-hand limit of the hypothetical equivalence range for \(\pi_+/(1-\pi_0) - 1/2\)

x

row vector with the \(m\) observations making up Sample1 as components

y

row vector with the \(n\) observations making up Sample2 as components

Value

alpha

significance level

m

size of Sample 1

n

size of Sample 2

eps1_

absolute value of the left-hand limit of the hypothetical equivalence range for \(\pi_+/(1-\pi_0) - 1/2\)

eps2_

right-hand limit of the hypothetical equivalence range for \(\pi_+/(1-\pi_0) - 1/2\)

WXY_TIE

observed value of the \(U\)-statistics -- based estimator of \(\pi_+/(1-\pi_0)\)

SIGMAH

square root of the estimated asymtotic variance of \(W_+/(1-W_0)\)

CRIT

upper critical bound to \(|W_+/(1-W_0) - 1/2 - (\varepsilon^\prime_2-\varepsilon^\prime_1)/2|/\hat{\sigma}\)

REJ

indicator of a positive [=1] vs negative [=0] rejection decision to be taken with the data under analysis

Details

Notation: \(\pi_+\) and \(\pi_0\) stands for the functional defined by \(\pi_+ = P[X>Y]\) and \(\pi_0 = P[X=Y]\), respectively, with \(X\sim F \equiv\) cdf of Population 1 being independent of \(Y\sim G \equiv\) cdf of Population 2.

References

Wellek S, Hampel B: A distribution-free two-sample equivalence test allowing for tied observations. Biometrical Journal 41 (1999), 171-186.

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 6.4.

Examples

Run this code
# NOT RUN {
x <- c(1,1,3,2,2,3,1,1,1,2,1,2,2,2,1,2,1,3,2,1,2,1,1,1,1,1,1,1,1,1,1,1,2,1,3,1,3,2,1,1,
       2,1,2,1,1,2,2,1,2,1,1,1,1,1,2,2,1,2,2,1,3,1,2,1,1,2,2,1,2,2,1,1,1,3,2,1,1,1,2,1,
       3,3,3,1,2,1,2,2,1,1,1,2,2,1,1,2,1,1,2,3,1,3,2,1,1,1,1,2,2,2,1,1,2,2,3,2,1,2,1,1,
       2,2,1,2,2,2,1,1,2,3,2,1,3,2,1,1,1,2,2,2,2,1,2,2,1,1,1,1,2,1,1,1,2,1,2,2,1,2,2,2,
       2,1,1,2,1,2,2,1,1,1,1,3,1,1,2,2,1,1,1,2,2,2,1,2,3,2,2,1,2,1,2,1,1,2,1,2,2,1,1,1,
       2,2,2,2)
y <- c(2,1,2,2,1,1,2,2,2,1,1,2,1,3,3,1,1,1,1,1,1,2,2,3,1,1,1,3,1,1,1,1,1,1,1,2,2,3,2,1,
       2,2,2,1,2,1,1,2,2,1,2,1,1,1,1,2,1,2,1,1,3,1,1,1,2,2,2,1,1,1,1,2,1,2,1,1,2,2,2,2,
       2,1,1,1,3,2,2,2,1,2,3,1,2,1,1,1,2,1,3,3,1,2,2,2,2,2,2,1,2,1,1,1,1,2,2,1,1,1,1,2,
       1,3,1,1,2,1,2,1,2,2,2,1,2,2,2,1,1,1,2,1,2,1,2,1,1,1,2,1,2,2,1,1,1,1,2,2,3,1,3,1,
       1,2,2,2,1,1,1,1,2,1,1,3,2,2,3,1,2,2,1,1,2,1,1,2,1,2,2,1,2,1,2,2,2,1,1,1,1,1,1,1,
       1,1,1,2,1,3,2,2,1,1,1,2,2,1,1,2,1,2,1,2,2,2,1,2,3,1,1,2,1,2,2,1,1,1,1,2,2,2,1,1,
       3,2,1,2,2,2,1,1,1,2,1,2,2,1,2,1,1,2)
mwtie_fr(3,0.05,204,258,0.10,0.10,x,y)
# }

Run the code above in your browser using DataLab