Implementation of the algorithm presented in \(\S\) 10.3.3 of Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition.
po_pbibe(n,eps,pio,zq,s,tol,sw,ihmax)sample size
equivalence margin to an individual log-bioavailability ratio
prespecified lower bound to the probability of obtaining an individual log-bioavailability ratio falling in the equivalence range \((-\varepsilon,\varepsilon)\)
mean log-bioavailability ratio observed in the sample under analysis
square root of the sample variance of the log-bioavailability ratios
maximum numerical error allowed for transforming the hypothesis of PBIBE into a region in the parameter space of the log-normal distribution assumed to underlie the given sample of individual bioavailability ratios
step width used in the numerical procedure yielding results at a level of accuracy specified by the value chosen for tol
maximum number of interval halving steps to be carried out in finding the region specified in the parameter space according to the criterion of PBIBE
sample size
equivalence margin to an individual log-bioavailability ratio
prespecified lower bound to the probability of obtaining an individual log-bioavailability ratio falling in the equivalence range \((-\varepsilon,\varepsilon)\)
mean log-bioavailability ratio observed in the sample under analysis
square root of the sample variance of the log-bioavailability ratios
maximum numerical error allowed for transforming the hypothesis of PBIBE into a region in the parameter space of the log-normal distribution assumed to underlie the given sample of individual bioavailability ratios
step width used in the numerical procedure yielding results at a level of accuracy specified by the value chosen for tol
maximum number of interval halving steps to be carried out in finding the region specified in the parameter space according to the criterion of PBIBE
posterior probability of the alternative hypothesis of PBIBE
The program uses 96-point Gauss-Legendre quadrature.
Wellek S: Bayesian construction of an improved parametric test for probability-based individual bioequivalence. Biometrical Journal 42 (2000), 1039-52.
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 10.3.3.
# NOT RUN {
po_pbibe(20,0.25,0.75,0.17451,0.04169, 10e-10,0.01,100)
# }
Run the code above in your browser using DataLab