Learn R Programming

EQUIVNONINF (version 1.0.2)

postmys: Bayesian posterior probability of the alternative hypothesis in the setting of the one-sample t-test for equivalence

Description

Evaluation of the integral appearing on the right-hand side of equation (3.6) on p. 38 of Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition

Usage

postmys(n,dq,sd,eps1,eps2,tol)

Arguments

n

sample size

dq

mean within-pair difference observed in the sample under analysis

sd

square root of the sample variance of the within-pair differences

eps1

absolute value of the left-hand limit of the hypothetical equivalence range for \(\delta/\sigma_D\)

eps2

right-hand limit of the hypothetical equivalence range for \(\delta/\sigma_D\)

tol

tolerance for the error induced through truncating the range of integration on the right

Value

n

sample size

dq

mean within-pair difference observed in the sample under analysis

sd

square root of the sample variance of the within-pair differences

eps1

absolute value of the left-hand limit of the hypothetical equivalence range for \(\delta/\sigma_D\)

eps2

right-hand limit of the hypothetical equivalence range for \(\delta/\sigma_D\)

tol

tolerance for the error induced through truncating the range of integration on the right

PPOST

posterior probability of the set of all \((\delta,\sigma_D)\) such that \(-\varepsilon_1 < \delta/\sigma_D < \varepsilon_2\)

Details

The program uses 96-point Gauss-Legendre quadrature.

References

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 3.2.

Examples

Run this code
# NOT RUN {
postmys(23,0.16,3.99,0.5,0.5,1e-6)
# }

Run the code above in your browser using DataLab