Learn R Programming

EQUIVNONINF (version 1.0.2)

pow_abe: Confidence innterval inclusion test for average bioequivalence: exact power against an arbitrary specific alternative

Description

Evaluation of the integral on the right-hand side of equation (10.11) of p. 317 of Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition

Usage

pow_abe(m,n,alpha,del_0,del,sig)

Arguments

m

sample size in sequence group T(est)/R(eference)

n

sample size in sequence group R(eference)/T(est)

alpha

significance level

del_0

equivalence margin to the absolute value of the log-ratio \(\mu^*_T\) and \(\mu^*_R\) of the formulation effects

del

assumed true value of \(| \log(\mu^*_T/\mu^*_R) |\), with \(0\le\delta < \delta_0\)

sig

theoretical standard deviation of the log within-subject bioavailability ratios in each sequence group

Value

m

sample size in sequence group T(est)/R(eference)

n

sample size in sequence group R(eference)/T(est)

alpha

significance level

del_0

equivalence margin to the absolute value of the log-ratio \(\mu^*_T\) and \(\mu^*_R\) of the formulation effects

del

assumed true value of \(| \log(\mu^*_T/\mu^*_R) |\), with \(0\le\delta < \delta_0\)

POW_ABE

power of the interval inclusion test for average bioequivalence against the specific alternative given by \((\delta,\sigma)\)

Details

The program uses 96-point Gauss-Legendre quadrature.

References

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 10.2.1.

Examples

Run this code
# NOT RUN {
pow_abe(12,13,0.05,log(1.25),log(1.25)/2,0.175624)
# }

Run the code above in your browser using DataLab