Analogue of the function srktie_d tailored for settings where the distribution of the within-subject differences is concentrated on a finite lattice. For details see Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition, pp.112-3.
srktie_m(n,alpha,eps1,eps2,w,d)sample size
significance level
absolute value of the left-hand limit of the hypothetical equivalence range for \(q_+/(1-q_0) - 1/2\)
right-hand limit of the hypothetical equivalence range for \(q_+/(1-q_0) - 1/2\)
span of the lattice in which the intraindividual differences take their values
row vector with the intraindividual differences for all \(n\) pairs as components
sample size
significance level
absolute value of the left-hand limit of the hypothetical equivalence range for \(q_+/(1-q_0) - 1/2\)
right-hand limit of the hypothetical equivalence range for \(q_+/(1-q_0) - 1/2\)
span of the lattice in which the intraindividual differences take their values
observed value of the \(U\)-statistics estimator of \(q_+\)
observed value of the \(U\)-statistics estimator of \(q_0\)
observed value of \(U_+/(1-U_0)\)
square root of the estimated asymtotic variance of \(\sqrt{n}U_+/(1-U_0)\)
upper critical bound to \(\sqrt{n}|U_+/(1-U_0) - 1/2 - (\varepsilon_2-\varepsilon_1)/2|/\hat{\tau}\)
indicator of a positive [=1] vs negative [=0] rejection decision to be taken with the data under analysis
Notation: \(q_+\) and \(q_0\) stands for the functional defined by \(q_+ = P[D_i+D_j>0]\) and \(q_0 = P[D_i+D_j=0]\), respectively, with \(D_i\) and \(D_j\) as the intraindividual differences observed in two individuals independently selected from the underlying bivariate population.
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, pp. 112-114.
# NOT RUN {
d <- c(0.8,0.2,0.0,-0.1,-0.3,0.3,-0.1,0.4,0.6,0.2,0.0,-0.2,-0.3,0.0,0.1,0.3,-0.3,
0.1,-0.2,-0.5,0.2,-0.1,0.2,-0.1)
srktie_m(24,0.05,0.2602,0.2602,0.1,d)
# }
Run the code above in your browser using DataLab