Learn R Programming

EQUIVNONINF (version 1.0.2)

tt1st: Critical constants and power against the null alternative of the one-sample t-test for equivalence with an arbitrary, maybe nonsymmetric choice of the limits of the equivalence range

Description

The function computes the critical constants defining the uniformly most powerful invariant test for the problem \(\delta/\sigma_D \le \theta_1\) or \(\delta/\sigma_D \ge \theta_2\) versus \(\theta_1 < \delta/\sigma_D < \theta_2\), with \((\theta_1,\theta_2)\) as a fixed nondegenerate interval on the real line. In addition, tt1st outputs the power against the null alternative \(\delta = 0\).

Usage

tt1st(n,alpha,theta1,theta2,tol,itmax)

Arguments

n

sample size

alpha

significance level

theta1

lower equivalence limit to \(\delta/\sigma_D\)

theta2

upper equivalence limit to \(\delta/\sigma_D\)

tol

tolerable deviation from \(\alpha\) of the rejection probability at either boundary of the hypothetical equivalence interval

itmax

maximum number of iteration steps

Value

n

sample size

alpha

significance level

theta1

lower equivalence limit to \(\delta/\sigma_D\)

theta2

upper equivalence limit to \(\delta/\sigma_D\)

IT

number of iteration steps performed until reaching the stopping criterion corresponding to TOL

C1

left-hand limit of the critical interval for the one-sample \(t\)-statistic

C2

right-hand limit of the critical interval for the one-sample \(t\)-statistic

ERR1

deviation of the rejection probability from \(\alpha\) under \(\delta/\sigma_D = \theta_1\)

ERR2

deviation of the rejection probability from \(\alpha\) under \(\delta/\sigma_D = \theta_2\)

POW0

power of the UMPI test against the alternative \(\delta = 0\)

References

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 5.3.

Examples

Run this code
# NOT RUN {
tt1st(36,0.05, -0.4716,0.3853,1e-10,50)
# }

Run the code above in your browser using DataLab