Learn R Programming

EQUIVNONINF (version 1.0.2)

tt2st: Critical constants and power against the null alternative of the two-sample t-test for equivalence with an arbitrary, maybe nonsymmetric choice of the limits of the equivalence range

Description

The function computes the critical constants defining the uniformly most powerful invariant test for the problem \((\xi-\eta)/\sigma \le -\varepsilon_1\) or \((\xi-\eta)/\sigma \ge \varepsilon_2\) versus \(-\varepsilon_1 < (\xi-\eta)/\sigma < \varepsilon_2\), with \(\xi\) and \(\eta\) denoting the expected values of two normal distributions with common variance \(\sigma^2\) from which independent samples are taken. In addition, tt2st outputs the power against the null alternative \(\xi = \eta\).

Usage

tt2st(m,n,alpha,eps1,eps2,tol,itmax)

Arguments

m

size of the sample from \({\cal N}(\xi,\sigma^2)\)

n

size of the sample from \({\cal N}(\eta,\sigma^2)\)

alpha

significance level

eps1

absolute value of the lower equivalence limit to \((\xi-\eta)/\sigma\)

eps2

upper equivalence limit to \((\xi-\eta)/\sigma\)

tol

tolerable deviation from \(\alpha\) of the rejection probability at either boundary of the hypothetical equivalence interval

itmax

maximum number of iteration steps

Value

m

size of the sample from \({\cal N}(\xi,\sigma^2)\)

n

size of the sample from \({\cal N}(\eta,\sigma^2)\)

alpha

significance level

eps1

absolute value of the lower equivalence limit to \((\xi-\eta)/\sigma\)

eps2

upper equivalence limit to \((\xi-\eta)/\sigma\)

IT

number of iteration steps performed until reaching the stopping criterion corresponding to TOL

C1

left-hand limit of the critical interval for the two-sample \(t\)-statistic

C2

right-hand limit of the critical interval for the two-sample \(t\)-statistic

ERR1

deviation of the rejection probability from \(\alpha\) under \((\xi-\eta)/\sigma= -\varepsilon_1\)

ERR2

deviation of the rejection probability from \(\alpha\) under \((\xi-\eta)/\sigma= \varepsilon_2\)

POW0

power of the UMPI test against the alternative \(\xi = \eta\)

References

Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 6.1.

Examples

Run this code
# NOT RUN {
tt2st(12,12,0.05,0.50,1.00,1e-10,50)
# }

Run the code above in your browser using DataLab