The function computes the critical constants defining the uniformly most powerful unbiased test for equivalence of two binomial distributions with parameters \(p_1\) and \(p_2\) in terms of the odds ratio. Like the ordinary Fisher type test of the null hypothesis \(p_1 = p_2\), the test is conditional on the total number \(S\) of successes in the pooled sample.
bi2st(alpha,m,n,s,rho1,rho2)significance level
size of Sample 1
size of Sample 2
observed total count of successes
lower limit of the hypothetical equivalence range for the odds ratio \(\varrho = \frac{p_1(1-p_2)}{p_2(1-p_1)}\)
upper limit of the hypothetical equivalence range for \(\varrho\)
significance level
size of Sample 1
size of Sample 2
observed total count of successes
lower limit of the hypothetical equivalence range for the odds ratio \(\varrho = \frac{p_1(1-p_2)}{p_2(1-p_1)}\)
upper limit of the hypothetical equivalence range for \(\varrho\)
left-hand limit of the critical interval for the number \(X\) of successes observed in Sample 1
right-hand limit of the critical interval for \(X\)
probability of rejecting the null hypothesis when it turns out that \(X=C_1\)
probability of rejecting the null hypothesis for \(X=C_2\)
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 6.6.4.
# NOT RUN {
bi2st(.05,225,119,171, 2/3, 3/2)
# }
Run the code above in your browser using DataLab