bi2ste2: Sample sizes for the exact Fisher type test for noninferiority
Description
Sample sizes for the exact Fisher type test for noninferiority
Usage
bi2ste2(eps, alpha, p1, p2, bet, qlambd)
Arguments
eps
noninferiority margin to the odds ratio
alpha
significance level
p1
success rate in Population 1
p2
success rate in Population 2
bet
target power value
qlambd
sample size ratio \(m/n\)
Value
eps
noninferiority margin to the odds ratio
alpha
significance level
p1
success rate in Population 1
p2
success rate in Population 2
bet
target power value
qlambd
sample size ratio \(m/n\)
M
minimum size of Sample 1
N
minimum size of Sample 2
POW
power of the randomized UMPU test attained with the computed values of m, n
Details
The program computes the smallest sample sizes \(m\),\(n\) satisfying
\(m/n = \lambda\) required for ensuring that the power of the randomized UMPU test does not
fall below \(\beta\).
References
Wellek S: Testing statistical hypotheses of equivalence and
noninferiority. Second edition. Boca Raton:
Chapman & Hall/CRC Press, 2010, 6.6.1.