Implementation of the interval estimation procedure described on pp. 305-6 of Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition.
cf_reh_exact(X1,X2,X3,alpha,SW,TOL,ITMAX)count of homozygotes of the first kind [\(\leftrightarrow\) genotype AA]
count of heterozygotes [\(\leftrightarrow\) genotype AB]
count of homozygotes of the second kind [\(\leftrightarrow\) genotype BB]
1 - confidence level
width of the search grid for determining an interval covering the parameter point at which the conditional distribution function takes value \(\alpha\) and \(1-\alpha\), respectively
numerical tolerance to the deviation between the computed confidence limits and their exact values
maximum number of interval-halving steps
count of homozygotes of the first kind [\(\leftrightarrow\) genotype AA]
count of heterozygotes [\(\leftrightarrow\) genotype AB]
count of homozygotes of the second kind [\(\leftrightarrow\) genotype BB]
1 - confidence level
width of the search grid for determining an interval covering the parameter point at which the conditional distribution function takes value \(\alpha\) and \(1-\alpha\), respectively
numerical tolerance to the deviation between the computed confidence limits and their exact values
maximum number of interval-halving steps
exact conditional lower \((1-\alpha)\)-confidence bound to REH
exact conditional upper \((1-\alpha)\)-confidence bound to REH
The program exploits the structure of the family of all genotype distributions, which is 2-parameter exponential with \(\log(REH)\) as one of these parameters.
Wellek S, Goddard KAB, Ziegler A: A confidence-limit-based approach to the assessment of Hardy-Weinberg equilibrium. Biometrical Journal 52 (2010), 253-270.
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 9.4.3.
# NOT RUN {
cf_reh_exact(34,118,96,.05,.1,1E-4,25)
# }
Run the code above in your browser using DataLab