The function computes the critical constants defining the uniformly most powerful test for the problem \(\sigma \le 1/(1 + \varepsilon)\) or \(\sigma\ge (1 + \varepsilon)\) versus \(1/(1 + \varepsilon) < \sigma < (1 + \varepsilon)\), with \(\sigma\) denoting the scale parameter [\(\equiv\) reciprocal hazard rate] of an exponential distribution.
exp1st(alpha,tol,itmax,n,eps)significance level
tolerable deviation from \(\alpha\) of the rejection probability at either boundary of the hypothetical equivalence interval
maximum number of iteration steps
sample size
margin determining the hypothetical equivalence range symmetrically on the log-scale
significance level
tolerable deviation from \(\alpha\) of the rejection probability at either boundary of the hypothetical equivalence interval
maximum number of iteration steps
sample size
margin determining the hypothetical equivalence range symmetrically on the log-scale
number of iteration steps performed until reaching the stopping criterion corresponding to TOL
left-hand limit of the critical interval for \(T =\sum_{i=1}^n X_i\)
right-hand limit of the critical interval for \(T =\sum_{i=1}^n X_i\)
deviation of the rejection probability from \(\alpha\) under \(\sigma = 1/(1 + \varepsilon)\)
power of the randomized UMP test against the alternative \(\sigma = 1\)
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 4.2.
# NOT RUN {
exp1st(0.05,1.0e-10,100,80,0.3)
# }
Run the code above in your browser using DataLab