The function computes the critical constants defining the optimal test for the problem \(\sigma^2/\tau^2 \le \varrho_1\) or \(\sigma^2/\tau^2 \ge \varrho_2\) versus \(\varrho_1 < \sigma^2/\tau^2 < \varrho_2\), with \((\varrho_1,\varrho_2)\) as a fixed nonempty interval around unity.
fstretch(alpha,tol,itmax,ny1,ny2,rho1,rho2)significance level
tolerable deviation from \(\alpha\) of the rejection probability at either boundary of the hypothetical equivalence interval
maximum number of iteration steps
number of degrees of freedom of the estimator of \(\sigma^2\)
number of degrees of freedom of the estimator of \(\tau^2\)
lower equivalence limit to \(\sigma^2/\tau^2\)
upper equivalence limit to \(\sigma^2/\tau^2\)
significance level
tolerable deviation from \(\alpha\) of the rejection probability at either boundary of the hypothetical equivalence interval
maximum number of iteration steps
number of degrees of freedom of the estimator of \(\sigma^2\)
number of degrees of freedom of the estimator of \(\tau^2\)
lower equivalence limit to \(\sigma^2/\tau^2\)
upper equivalence limit to \(\sigma^2/\tau^2\)
number of iteration steps performed until reaching the stopping criterion corresponding to TOL
left-hand limit of the critical interval for $$T = \frac{n-1}{m-1} \sum_{i=1}^m (X_i-\overline{X})^2 / \sum_{j=1}^{n-1} (Y_j-\overline{Y})^2$$
right-hand limit of the critical interval for $$T = \frac{n-1}{m-1} \sum_{i=1}^m (X_i-\overline{X})^2 / \sum_{j=1}^{n-1} (Y_j-\overline{Y})^2$$
deviation of the rejection probability from \(\alpha\) under \(\sigma^2/\tau^2 = \varrho_1\)
power of the UMPI test against the alternative \(\sigma^2/\tau^2 = 1\)
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 6.5.
# NOT RUN {
fstretch(0.05, 1.0e-10, 50,40,45,0.5625,1.7689)
# }
Run the code above in your browser using DataLab