The function computes the critical constants defining the UMPU test for one-sided equivalence of the population distribution of a SNP, to a distribution being in Hardy-Weinberg equilibrium (HWE). A substantial deficit of heterozygotes is defined to occur when the true value of the parametric function \(\omega = \frac{\pi_2/2}{\sqrt{\pi_1\pi_3}}\) [called relative excess heterozygosity (REH)] falls below unity by more than some given margin \(\delta_0\). Like its two-sided counterpart [see the description of the R function gofhwex], the test is conditional on the total count \(S\) of alleles of the kind of interest.
gofhwex_1s(alpha,n,s,del0)significance level
number of genotyped individuals
observed count of alleles of the kind of interest
noninferiority margin for \(\omega\), which has to satisfy \(\omega > 1-\delta_0\) under the alternative hypothesis to be established
significance level
number of genotyped individuals
observed count of alleles of the kind of interest
noninferiority margin for \(\omega\), which has to satisfy \(\omega > 1-\delta_0\) under the alternative hypothesis to be established
left-hand limit of the critical interval for the observed number \(X_2\) of heterozygotes
probability of rejecting the null hypothesis when it turns out that \(X_2=C\)
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, pp. 300-302.
# NOT RUN {
gofhwex_1s(0.05,133,65,1-1/1.96)
# }
Run the code above in your browser using DataLab