The program determines through iteration the largest nominal level \(\alpha_0\) such that comparing the posterior probability of the alternative hypothesis \(K_1: \delta > -\delta_0\) to the lower bound \(1-\alpha_0\) generates a critical region whose size does not exceed the target significance level \(\alpha\). In addition, exact values of the power against specific parameter configurations with \(\delta = 0\) are output.
mcnby_ni(N,DEL0,K1,K2,K3,NSUB,SW,ALPHA,MAXH)sample size
noninferiority margin to the difference of the parameters of the marginal binomial distributions under comparison
Parameter 1 of the Dirichlet prior for the family of trinomial distributions
Parameter 2 of the Dirichlet prior for the family of trinomial distributions
Parameter 3 of the Dirichlet prior for the family of trinomial distributions
number of subintervals for partitioning the range of integration
width of the search grid for determining the maximum of the rejection probability on the common boundary of the hypotheses
target significance level
maximum number of interval halving steps to be carried out in finding the maximally raised nominal level
sample size
noninferiority margin to the difference of the parameters of the marginal binomial distributions under comparison
Parameter 1 of the Dirichlet prior for the family of trinomial distributions
Parameter 2 of the Dirichlet prior for the family of trinomial distributions
Parameter 3 of the Dirichlet prior for the family of trinomial distributions
number of subintervals for partitioning the range of integration
width of the search grid for determining the maximum of the rejection probability on the common boundary of the hypotheses
target significance level
maximum number of interval halving steps to be carried out in finding the maximally raised nominal level
result of the search for the largest admissible nominal level
size of the critical region corresponding to \(\alpha_0\)
size of the critical region of test at uncorrected nominal level \(\alpha\)
power against 7 different parameter configurations with \(\delta =0\)
The program uses 96-point Gauss-Legendre quadrature on each of the NSUB intervals into which the range of integration is partitioned.
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 5.2.3.
# NOT RUN {
mcnby_ni(25,.10,.5,.5,.5,10,.05,.05,5)
# }
Run the code above in your browser using DataLab