Evaluation of the integral on the right-hand side of Equation (5.24) on p. 88 of Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition.
mcnby_ni_pp(N,DEL0,N10,N01)sample size
noninferiority margin to the difference of the parameters of the marginal binomial distributions under comparison
count of pairs with \((X,Y) = (1,0)\)
count of pairs with \((X,Y) = (0,1)\)
sample size
noninferiority margin to the difference of the parameters of the marginal binomial distributions under comparison
count of pairs with \((X,Y) = (1,0)\)
count of pairs with \((X,Y) = (0,1)\)
posterior probability of the alternative hypothesis \(K_1: \delta > -\delta_0\) with respect to the noninformative prior determined according to Jeffrey's rule
The program uses 96-point Gauss-Legendre quadrature on each of 10 subintervals into which the range of integration is partitioned.
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 5.2.3.
# NOT RUN {
mcnby_ni_pp(72,0.05,4,5)
# }
Run the code above in your browser using DataLab