Evaluation of the integral appearing on the right-hand side of equation (3.6) on p. 38 of Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition
postmys(n,dq,sd,eps1,eps2,tol)sample size
mean within-pair difference observed in the sample under analysis
square root of the sample variance of the within-pair differences
absolute value of the left-hand limit of the hypothetical equivalence range for \(\delta/\sigma_D\)
right-hand limit of the hypothetical equivalence range for \(\delta/\sigma_D\)
tolerance for the error induced through truncating the range of integration on the right
sample size
mean within-pair difference observed in the sample under analysis
square root of the sample variance of the within-pair differences
absolute value of the left-hand limit of the hypothetical equivalence range for \(\delta/\sigma_D\)
right-hand limit of the hypothetical equivalence range for \(\delta/\sigma_D\)
tolerance for the error induced through truncating the range of integration on the right
posterior probability of the set of all \((\delta,\sigma_D)\) such that \(-\varepsilon_1 < \delta/\sigma_D < \varepsilon_2\)
The program uses 96-point Gauss-Legendre quadrature.
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 3.2.
# NOT RUN {
postmys(23,0.16,3.99,0.5,0.5,1e-6)
# }
Run the code above in your browser using DataLab