Evaluation of the integral on the right-hand side of equation (10.11) of p. 317 of Wellek S (2010) Testing statistical hypotheses of equivalence and noninferiority. Second edition
pow_abe(m,n,alpha,del_0,del,sig)sample size in sequence group T(est)/R(eference)
sample size in sequence group R(eference)/T(est)
significance level
equivalence margin to the absolute value of the log-ratio \(\mu^*_T\) and \(\mu^*_R\) of the formulation effects
assumed true value of \(| \log(\mu^*_T/\mu^*_R) |\), with \(0\le\delta < \delta_0\)
theoretical standard deviation of the log within-subject bioavailability ratios in each sequence group
sample size in sequence group T(est)/R(eference)
sample size in sequence group R(eference)/T(est)
significance level
equivalence margin to the absolute value of the log-ratio \(\mu^*_T\) and \(\mu^*_R\) of the formulation effects
assumed true value of \(| \log(\mu^*_T/\mu^*_R) |\), with \(0\le\delta < \delta_0\)
power of the interval inclusion test for average bioequivalence against the specific alternative given by \((\delta,\sigma)\)
The program uses 96-point Gauss-Legendre quadrature.
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 10.2.1.
# NOT RUN {
pow_abe(12,13,0.05,log(1.25),log(1.25)/2,0.175624)
# }
Run the code above in your browser using DataLab