The program computes for each possible value of the number \(n_0\) of zero observations the power conditional on \(N_0 = n_0\) and averages these conditional power values with respect to the distribution of \(N_0\). Equivalence is defined in terms of the logarithm of the ratio \(p_+/p_-\), where \(p_+\) and \(p_-\) denotes the probability of obtaining a positive and negative sign, respectively.
powsign(alpha,n,eps1,eps2,poa)significance level
sample size
absolute value of the lower limit of the hypothetical equivalence range for \(\log(p_+/p_-)\).
upper limit of the hypothetical equivalence range for \(\log(p_+/p_-)\).
probability of a tie under the alternative of interest
significance level
sample size
absolute value of the lower limit of the hypothetical equivalence range for \(\log(p_+/p_-)\).
upper limit of the hypothetical equivalence range for \(\log(p_+/p_-)\).
probability of a tie under the alternative of interest
power of the nonrandomized version of the test against the alternative \(p_+ = p_- = (1-p_\circ)/2\)
power of the randomized UMPU test against the alternative \(p_+ = p_- = (1-p_\circ)/2\)
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 5.1.
# NOT RUN {
powsign(0.06580,50,0.847298,0.847298,0.26)
# }
Run the code above in your browser using DataLab