srktie_d: Generalized signed rank test for equivalence for tied data: test statistic and
critical upper bound
Description
Implementation of a generalized version of the signed-rank test for equivalence
allowing for arbitrary patterns of ties between the within-subject differences.
For details see Wellek S (2010) Testing statistical hypotheses of equivalence and
noninferiority. Second edition, \(\S\) 5.5.
Usage
srktie_d(n,alpha,eps1,eps2,d)
Arguments
n
sample size
alpha
significance level
eps1
absolute value of the left-hand limit of the hypothetical equivalence range for
\(q_+/(1-q_0) - 1/2\)
eps2
right-hand limit of the hypothetical equivalence range for \(q_+/(1-q_0) - 1/2\)
d
row vector with the intraindividual differences for all \(n\) pairs as components
Value
n
sample size
alpha
significance level
eps1
absolute value of the left-hand limit of the hypothetical equivalence range for
\(q_+/(1-q_0) - 1/2\)
eps2
right-hand limit of the hypothetical equivalence range for \(q_+/(1-q_0) - 1/2\)
U_pl
observed value of the \(U\)-statistics estimator of \(q_+\)
U_0
observed value of the \(U\)-statistics estimator of \(q_0\)
UAS_PL
observed value of \(U_+/(1-U_0)\)
TAUHAS
square root of the estimated asymtotic variance of \(\sqrt{n}U_+/(1-U_0)\)
CRIT
upper critical bound to \(\sqrt{n}|U_+/(1-U_0) - 1/2 -
(\varepsilon_2-\varepsilon_1)/2|/\hat{\tau}\)
REJ
indicator of a positive [=1] vs negative [=0] rejection decision to be taken with
the data under analysis
Details
Notation: \(q_+\) and \(q_0\) stands for the functional defined by
\(q_+ = P[D_i+D_j>0]\) and \(q_0 = P[D_i+D_j=0]\), respectively,
with \(D_i\) and \(D_j\) as the intraindividual differences observed in two individuals
independently selected from the underlying bivariate population.
References
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition.
Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 5.5.
# NOT RUN {d <- c(0.8,0.2,0.0,-0.1,-0.3,0.3,-0.1,0.4,0.6,0.2,0.0,-0.2,-0.3,0.0,0.1,0.3,-0.3,
0.1,-0.2,-0.5,0.2,-0.1,0.2,-0.1)
srktie_d(24,0.05,0.2602,0.2602,d)
# }