The function computes the critical constants defining the uniformly most powerful invariant test for the problem \(\delta/\sigma_D \le \theta_1\) or \(\delta/\sigma_D \ge \theta_2\) versus \(\theta_1 < \delta/\sigma_D < \theta_2\), with \((\theta_1,\theta_2)\) as a fixed nondegenerate interval on the real line. In addition, tt1st outputs the power against the null alternative \(\delta = 0\).
tt1st(n,alpha,theta1,theta2,tol,itmax)sample size
significance level
lower equivalence limit to \(\delta/\sigma_D\)
upper equivalence limit to \(\delta/\sigma_D\)
tolerable deviation from \(\alpha\) of the rejection probability at either boundary of the hypothetical equivalence interval
maximum number of iteration steps
sample size
significance level
lower equivalence limit to \(\delta/\sigma_D\)
upper equivalence limit to \(\delta/\sigma_D\)
number of iteration steps performed until reaching the stopping criterion corresponding to TOL
left-hand limit of the critical interval for the one-sample \(t\)-statistic
right-hand limit of the critical interval for the one-sample \(t\)-statistic
deviation of the rejection probability from \(\alpha\) under \(\delta/\sigma_D = \theta_1\)
deviation of the rejection probability from \(\alpha\) under \(\delta/\sigma_D = \theta_2\)
power of the UMPI test against the alternative \(\delta = 0\)
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 5.3.
# NOT RUN {
tt1st(36,0.05, -0.4716,0.3853,1e-10,50)
# }
Run the code above in your browser using DataLab