The function computes the critical constants defining the uniformly most powerful invariant test for the problem \((\xi-\eta)/\sigma \le -\varepsilon_1\) or \((\xi-\eta)/\sigma \ge \varepsilon_2\) versus \(-\varepsilon_1 < (\xi-\eta)/\sigma < \varepsilon_2\), with \(\xi\) and \(\eta\) denoting the expected values of two normal distributions with common variance \(\sigma^2\) from which independent samples are taken. In addition, tt2st outputs the power against the null alternative \(\xi = \eta\).
tt2st(m,n,alpha,eps1,eps2,tol,itmax)size of the sample from \({\cal N}(\xi,\sigma^2)\)
size of the sample from \({\cal N}(\eta,\sigma^2)\)
significance level
absolute value of the lower equivalence limit to \((\xi-\eta)/\sigma\)
upper equivalence limit to \((\xi-\eta)/\sigma\)
tolerable deviation from \(\alpha\) of the rejection probability at either boundary of the hypothetical equivalence interval
maximum number of iteration steps
size of the sample from \({\cal N}(\xi,\sigma^2)\)
size of the sample from \({\cal N}(\eta,\sigma^2)\)
significance level
absolute value of the lower equivalence limit to \((\xi-\eta)/\sigma\)
upper equivalence limit to \((\xi-\eta)/\sigma\)
number of iteration steps performed until reaching the stopping criterion corresponding to TOL
left-hand limit of the critical interval for the two-sample \(t\)-statistic
right-hand limit of the critical interval for the two-sample \(t\)-statistic
deviation of the rejection probability from \(\alpha\) under \((\xi-\eta)/\sigma= -\varepsilon_1\)
deviation of the rejection probability from \(\alpha\) under \((\xi-\eta)/\sigma= \varepsilon_2\)
power of the UMPI test against the alternative \(\xi = \eta\)
Wellek S: Testing statistical hypotheses of equivalence and noninferiority. Second edition. Boca Raton: Chapman & Hall/CRC Press, 2010, \(\S\) 6.1.
# NOT RUN {
tt2st(12,12,0.05,0.50,1.00,1e-10,50)
# }
Run the code above in your browser using DataLab